'use strict';

const path = require('path');

const importConfig = require('./importer');

const { getAppRootDir } = require('../utils/pathing');
const { logError } = require('../utils/logger');

/**
 * @param  {Object} configFile
 * @param  {string} appRootDir
 * @param  {string} componentName
 * @param  {string} componentPath
 * @returns templatePathsArray
 */
const mapTemplatePaths = (configFile, appRootDir, componentName, componentPath) => configFile.templates.map(template => {
  const folderName = template.folderName || '';

  return {
    filePath: path.join(appRootDir, componentPath, componentName, folderName, template.fileName || componentName + template.extension),
    templatePath: `${path.join(appRootDir, configFile.templatesDirectory, template.templateName)}`
  };
});

/**
 * @param  {Object} configFile
 * @param  {string} appRootDir
 * @param  {string} componentName
 * @param  {string} componentPath
 * @returns folderPathsArray
 */
const mapFolderPaths = (configFile, appRootDir, componentName, componentPath) => {
  return configFile.templates.map(({ folderName }) => {
    if (folderName) {
      return path.join(appRootDir, componentPath, componentName, folderName);
    }
  }).filter(folder => folder);
};

/**
 * @param  {string} configPath
 * @param  {string} componentName
 * @param  {string} componentPath
 * @returns folderPathsArray
 */
const mapConfigWithTemplates = async (configPath, componentName, componentPath) => {
  const appRootDir = getAppRootDir();
  const configFile = await importConfig(appRootDir, configPath);

  if (path.isAbsolute(configFile.templatesDirectory)) {
    throw logError('cct.config[templatesDirectory] path was absolute. The provided path must be relative');
  }

  const folderPaths = mapFolderPaths(configFile, appRootDir, componentName, componentPath);
  const templatePaths = mapTemplatePaths(configFile, appRootDir, componentName, componentPath);

  return {
    templatePaths,
    folderPaths
  };
};

module.exports = mapConfigWithTemplates;