'use strict';

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const { logError } = require('../utils/logger.js');
const inquirer = require('inquirer');
const chalk = require('chalk');

const defaultArgs = require('../args/default');

/**
 * @param  {Object} options
 * @returns Array
 */
const createQuestions = options => {
  const questions = [{
    type: 'input',
    name: 'componentName',
    message: chalk.magenta('Please enter a component name'),
    when: () => !options.componentName,
    validate: compName => compName ? true : 'must be longer than 0 characters'
  }, {
    type: 'input',
    name: 'componentPath',
    message: chalk.magenta(`Please enter a folder path for the new component`),
    when: () => !options.componentPath,
    default: defaultArgs.componentPath
  }];

  return questions;
};

/**
 * @param  {Object} options
 * @returns Object
 */
const promptUser = async options => {
  const questions = createQuestions(options);

  let answers;

  try {
    answers = await inquirer.prompt(questions);
  } catch (err) {
    logError(err);
  }

  // default options + override with answers
  return (0, _extends3.default)({}, options, answers);
};

module.exports = promptUser;